import { Command, Element, Operation, Range, Node, NodeEntry } from '../..';
/**
 * The `Editor` interface stores all the state of a Slate editor. It is extended
 * by plugins that wish to add their own helpers and implement new behaviors.
 */
export interface Editor {
    children: Node[];
    selection: Range | null;
    operations: Operation[];
    marks: Record<string, any> | null;
    apply: (operation: Operation) => void;
    exec: (command: Command) => void;
    isInline: (element: Element) => boolean;
    isVoid: (element: Element) => boolean;
    normalizeNode: (entry: NodeEntry) => void;
    onChange: () => void;
    [key: string]: any;
}
export declare const Editor: {
    delete(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        distance?: number | undefined;
        unit?: "character" | "word" | "line" | "block" | undefined;
        reverse?: boolean | undefined;
        hanging?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    insertFragment(editor: Editor, fragment: Node[], options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        hanging?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    insertText(editor: Editor, text: string, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        voids?: boolean | undefined;
    }): void;
    collapse(editor: Editor, options?: {
        edge?: "start" | "end" | "anchor" | "focus" | undefined;
    }): void;
    deselect(editor: Editor): void;
    move(editor: Editor, options?: {
        distance?: number | undefined;
        unit?: "offset" | "character" | "word" | "line" | undefined;
        reverse?: boolean | undefined;
        edge?: "start" | "end" | "anchor" | "focus" | undefined;
    }): void;
    select(editor: Editor, target: import("../location").Location): void;
    setPoint(editor: Editor, props: Partial<import("../point").Point>, options: {
        edge?: "start" | "end" | "anchor" | "focus" | undefined;
    }): void;
    setSelection(editor: Editor, props: Partial<Range>): void;
    unhangRange(editor: Editor, range: Range, options?: {
        voids?: boolean | undefined;
    }): Range;
    insertNodes(editor: Editor, nodes: Editor | Element | import("../text").Text | Node[], options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: "block" | "element" | "inline" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<import("../text").Text> | ((node: Node, editor: Editor) => boolean) | import("../node").NodeMatch[] | undefined;
        hanging?: boolean | undefined;
        select?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    liftNodes(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: "block" | "element" | "inline" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<import("../text").Text> | ((node: Node, editor: Editor) => boolean) | import("../node").NodeMatch[] | undefined;
        mode?: "all" | "highest" | undefined;
        voids?: boolean | undefined;
    }): void;
    mergeNodes(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: "block" | "element" | "inline" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<import("../text").Text> | ((node: Node, editor: Editor) => boolean) | import("../node").NodeMatch[] | undefined;
        hanging?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    moveNodes(editor: Editor, options: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: "block" | "element" | "inline" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<import("../text").Text> | ((node: Node, editor: Editor) => boolean) | import("../node").NodeMatch[] | undefined;
        mode?: "all" | "highest" | undefined;
        to: import("../path").Path;
        voids?: boolean | undefined;
    }): void;
    removeNodes(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: "block" | "element" | "inline" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<import("../text").Text> | ((node: Node, editor: Editor) => boolean) | import("../node").NodeMatch[] | undefined;
        mode?: "all" | "highest" | undefined;
        hanging?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    setNodes(editor: Editor, props: Partial<Editor> | Partial<Element> | Partial<import("../text").Text>, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: "block" | "element" | "inline" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<import("../text").Text> | ((node: Node, editor: Editor) => boolean) | import("../node").NodeMatch[] | undefined;
        mode?: "all" | "highest" | undefined;
        hanging?: boolean | undefined;
        split?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    splitNodes(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: "block" | "element" | "inline" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<import("../text").Text> | ((node: Node, editor: Editor) => boolean) | import("../node").NodeMatch[] | undefined;
        always?: boolean | undefined;
        height?: number | undefined;
        voids?: boolean | undefined;
    }): void;
    unsetNodes(editor: Editor, props: string | string[], options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: "block" | "element" | "inline" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<import("../text").Text> | ((node: Node, editor: Editor) => boolean) | import("../node").NodeMatch[] | undefined;
        mode?: "all" | "highest" | undefined;
        split?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    unwrapNodes(editor: Editor, options: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: "block" | "element" | "inline" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<import("../text").Text> | ((node: Node, editor: Editor) => boolean) | import("../node").NodeMatch[] | undefined;
        mode?: "all" | "highest" | undefined;
        split?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    wrapNodes(editor: Editor, element: Element, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: "block" | "element" | "inline" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<import("../text").Text> | ((node: Node, editor: Editor) => boolean) | import("../node").NodeMatch[] | undefined;
        mode?: "all" | "highest" | undefined;
        split?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    isMatch(editor: Editor, node: Node, match: import("../node").NodeMatch): boolean;
    after(editor: Editor, at: import("../location").Location, options?: {
        distance?: number | undefined;
        unit?: "offset" | "character" | "word" | "line" | "block" | undefined;
    }): import("../point").Point | undefined;
    before(editor: Editor, at: import("../location").Location, options?: {
        distance?: number | undefined;
        unit?: "offset" | "character" | "word" | "line" | "block" | undefined;
    }): import("../point").Point | undefined;
    edges(editor: Editor, at: import("../location").Location): [import("../point").Point, import("../point").Point];
    elements(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: "block" | "element" | "inline" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<import("../text").Text> | ((node: Node, editor: Editor) => boolean) | import("../node").NodeMatch[] | undefined;
        mode?: "all" | "highest" | undefined;
        reverse?: boolean | undefined;
        voids?: boolean | undefined;
    }): Iterable<import("../element").ElementEntry>;
    end(editor: Editor, at: import("../location").Location): import("../point").Point;
    first(editor: Editor, at: import("../location").Location): NodeEntry;
    fragment(editor: Editor, at: import("../location").Location): import("../node").Descendant[];
    isEnd(editor: Editor, point: import("../point").Point, at: import("../location").Location): boolean;
    isEdge(editor: Editor, point: import("../point").Point, at: import("../location").Location): boolean;
    isStart(editor: Editor, point: import("../point").Point, at: import("../location").Location): boolean;
    last(editor: Editor, at: import("../location").Location): NodeEntry;
    leaf(editor: Editor, at: import("../location").Location, options?: {
        depth?: number | undefined;
        edge?: "start" | "end" | undefined;
    }): import("../text").TextEntry;
    levels(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        reverse?: boolean | undefined;
        voids?: boolean | undefined;
    }): Iterable<NodeEntry>;
    match(editor: Editor, at: import("../location").Location, match: import("../node").NodeMatch, options?: {
        voids?: boolean | undefined;
    }): NodeEntry | undefined;
    matches(editor: Editor, options: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: "block" | "element" | "inline" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<import("../text").Text> | ((node: Node, editor: Editor) => boolean) | import("../node").NodeMatch[] | undefined;
        reverse?: boolean | undefined;
    }): Iterable<NodeEntry>;
    next(editor: Editor, at: import("../location").Location, match?: "block" | "element" | "inline" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<import("../text").Text> | ((node: Node, editor: Editor) => boolean) | import("../node").NodeMatch[] | undefined, options?: {
        mode?: "all" | "highest" | undefined;
        voids?: boolean | undefined;
    }): NodeEntry | undefined;
    node(editor: Editor, at: import("../location").Location, options?: {
        depth?: number | undefined;
        edge?: "start" | "end" | undefined;
    }): NodeEntry;
    nodes(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | import("../location").Span | undefined;
        match?: "block" | "element" | "inline" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<import("../text").Text> | ((node: Node, editor: Editor) => boolean) | import("../node").NodeMatch[] | undefined;
        mode?: "all" | "highest" | undefined;
        reverse?: boolean | undefined;
        voids?: boolean | undefined;
    }): Iterable<NodeEntry>;
    parent(editor: Editor, at: import("../location").Location, options?: {
        depth?: number | undefined;
        edge?: "start" | "end" | undefined;
    }): import("../node").AncestorEntry;
    path(editor: Editor, at: import("../location").Location, options?: {
        depth?: number | undefined;
        edge?: "start" | "end" | undefined;
    }): import("../path").Path;
    point(editor: Editor, at: import("../location").Location, options?: {
        edge?: "start" | "end" | undefined;
    }): import("../point").Point;
    positions(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        unit?: "offset" | "character" | "word" | "line" | "block" | undefined;
        reverse?: boolean | undefined;
    }): Iterable<import("../point").Point>;
    previous(editor: Editor, at: import("../location").Location, match?: "block" | "element" | "inline" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<import("../text").Text> | ((node: Node, editor: Editor) => boolean) | import("../node").NodeMatch[] | undefined, options?: {
        mode?: "all" | "highest" | undefined;
        voids?: boolean | undefined;
    }): NodeEntry | undefined;
    range(editor: Editor, at: import("../location").Location, to?: Range | import("../path").Path | import("../point").Point | undefined): Range;
    start(editor: Editor, at: import("../location").Location): import("../point").Point;
    text(editor: Editor, at: import("../location").Location): string;
    texts(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: "block" | "element" | "inline" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<import("../text").Text> | ((node: Node, editor: Editor) => boolean) | import("../node").NodeMatch[] | undefined;
        mode?: "all" | "highest" | undefined;
        reverse?: boolean | undefined;
        voids?: boolean | undefined;
    }): Iterable<import("../text").TextEntry>;
    normalize(editor: Editor, options?: {
        force?: boolean | undefined;
    }): void;
    transform(editor: Editor, op: Operation): void;
    isEditor(value: any): value is Editor;
    isNormalizing(editor: Editor): boolean;
    marks(editor: Editor): Record<string, any> | null;
    pathRef(editor: Editor, path: import("../path").Path, options?: {
        affinity?: "backward" | "forward" | null | undefined;
    }): import("../path-ref").PathRef;
    pathRefs(editor: Editor): Set<import("../path-ref").PathRef>;
    pointRef(editor: Editor, point: import("../point").Point, options?: {
        affinity?: "backward" | "forward" | null | undefined;
    }): import("../point-ref").PointRef;
    pointRefs(editor: Editor): Set<import("../point-ref").PointRef>;
    rangeRef(editor: Editor, range: Range, options?: {
        affinity?: "backward" | "forward" | "outward" | "inward" | null | undefined;
    }): import("../range-ref").RangeRef;
    rangeRefs(editor: Editor): Set<import("../range-ref").RangeRef>;
    withoutNormalizing(editor: Editor, fn: () => void): void;
    hasBlocks(editor: Editor, element: Element): boolean;
    hasInlines(editor: Editor, element: Element): boolean;
    hasTexts(editor: Editor, element: Element): boolean;
    isEmpty(editor: Editor, element: Element): boolean;
};
//# sourceMappingURL=index.d.ts.map