import { Editor, Path, Point, PathRef, PointRef, Range, RangeRef } from '../../..';
export declare const NORMALIZING: WeakMap<Editor, boolean>;
export declare const PATH_REFS: WeakMap<Editor, Set<PathRef>>;
export declare const POINT_REFS: WeakMap<Editor, Set<PointRef>>;
export declare const RANGE_REFS: WeakMap<Editor, Set<RangeRef>>;
export declare const GeneralQueries: {
    /**
     * Check if a value is an `Editor` object.
     */
    isEditor(value: any): value is Editor;
    /**
     * Check if the editor is currently normalizing after each operation.
     */
    isNormalizing(editor: Editor): boolean;
    /**
     * Get the marks that would be added to text at the current selection.
     */
    marks(editor: Editor): Record<string, any> | null;
    /**
     * Create a mutable ref for a `Path` object, which will stay in sync as new
     * operations are applied to the editor.
     */
    pathRef(editor: Editor, path: Path, options?: {
        affinity?: "backward" | "forward" | null | undefined;
    }): PathRef;
    /**
     * Get the set of currently tracked path refs of the editor.
     */
    pathRefs(editor: Editor): Set<PathRef>;
    /**
     * Create a mutable ref for a `Point` object, which will stay in sync as new
     * operations are applied to the editor.
     */
    pointRef(editor: Editor, point: Point, options?: {
        affinity?: "backward" | "forward" | null | undefined;
    }): PointRef;
    /**
     * Get the set of currently tracked point refs of the editor.
     */
    pointRefs(editor: Editor): Set<PointRef>;
    /**
     * Create a mutable ref for a `Range` object, which will stay in sync as new
     * operations are applied to the editor.
     */
    rangeRef(editor: Editor, range: Range, options?: {
        affinity?: "backward" | "forward" | "outward" | "inward" | null | undefined;
    }): RangeRef;
    /**
     * Get the set of currently tracked range refs of the editor.
     */
    rangeRefs(editor: Editor): Set<RangeRef>;
    /**
     * Call a function, deferring normalization until after it completes.
     */
    withoutNormalizing(editor: Editor, fn: () => void): void;
};
//# sourceMappingURL=general.d.ts.map